ColorEmphasis

Struct ColorEmphasis 

pub struct ColorEmphasis {
    pub bits: u8,
}
Red, green, and/or blue color emphasis information.

This type is only used to communicate how a PixelBuffer should modulate its color output when it receives pixel information.

The the bits field is a bitset with 3 fields in its least significant bits:

7 6 5 4 3 2 1 0
x x x x x B G R
          | | |
          | | +- Red color emphasis.
          | +--- Blue color emphasis.
          +----- Green color emphasis.

The high 5 bits will never be set.

Fields

bits: u8