#[repr(C)]pub struct Sprite {
pub y: u8,
pub pattern_index: u8,
pub attributes: u8,
pub x: u8,
}Expand description
A floating graphic is rendered separately from tiles.
A sprite can be drawn to any position on the screen, and is either 8x8px or 8x16px in size. Each sprite uses one of 4 sprite palettes for color, which are separate from the 4 tile palettes.
Fields
y: u8Y coordinate of the sprite’s top-left corner.
pattern_index: u8The index for the sprite’s graphics. In 8x8px mode, this is relative to the sprite pattern table selected in the PPU ctrl register. In 8x16px mode, The least significant bit sets the bank, and the most significant 7 bits index into pairs of graphics within that bank.
attributes: u8A bit field configuring whether the sprite is flipped along the x or y axes, whether it is rendered in front of or behind tiles, and the sprite’s palette index.
x: u8X coordinate of the sprite’s top-left corner.